@@ -108,27 +108,33 @@ def INPUT(text,x,y,NOENTER=False, NPRINT=False):
             f = open("keys.txt", "a")
             PRINT = False
             key = getch.getch()
-            s = key.replace('b', '', 1)
-            d = s.replace("'", "")
-            if d == Fr'\x9c':
+            ESCCODES = ord(key)
+            if ESCCODES == 10:
+                break
+            elif ESCCODES == 127:
+                sys.stdout.write('\r' + (' ' * shutil.get_terminal_size()[0]))
+                print ("\033[A")
+            else:
+                pass
+            if key == Fr'\x9c':
                 f.write(u"\xa3")
-            elif d == 'Â':
+            elif key == 'Â':
                 pass
             else:
-                f.write(F"{d}")
+                f.write(F"{key}")
             if PRINT == True:
-                print(d)
+                print(key)
                 break
             PRINT = True
             # box = F'''
             # ╔═╗
             # ║{d}║
             # ╚═╝'''
-            if d == r"\r":
+            if key == r"\r":
                 pass
             else:
                 pass
-            if d == r"\x08":
+            if key == r"\x08":
                 sys.stdout.write('\r' + (' ' * shutil.get_terminal_size()[0]))
                 print ("\033[A")
                 sys.stdout.write("\x1b7\x1b[%d;%df%s\x1b8" % (x,y, f"{text}"))
@@ -136,12 +142,12 @@ def INPUT(text,x,y,NOENTER=False, NPRINT=False):
                 f.close()
                 os.remove("keys.txt")
             elif NOENTER == True:
-                if d == r"\r":
+                if key == r"\r":
                     pass
                 else:
                     f = open("keys.txt", "a")
-                    f.write(F"{d}")
-            elif d == r"\r":
+                    f.write(F"{key}")
+            elif key == r"\r":
                 f = open("keys.txt", "r")
                 e = f.read()
                 userinput = e.replace('\r', '')
